# How to contribute

For **development**, install the package dynamically and dev requirements with:

```bash
pip install -e .
pip install -r requirements-dev.txt
```

Everyone can contribute to CLI Config, and we value everyone’s contributions. Please see our
[contributing guidelines](https://github.com/valentingol/cliconfig/blob/main/CONTRIBUTING.md)
for more information 🤗
